@@ -85,7 +85,7 @@ void KNSBackendTest::testRetrieval()
     QVERIFY(!m_backend->isFetching() || spy.wait());
 
     const auto resources = getAllResources(m_backend);
-    foreach (AbstractResource *res, resources) {
+    for (AbstractResource *res : resources) {
         QVERIFY(!res->name().isEmpty());
         QVERIFY(!res->categories().isEmpty());
         QVERIFY(!res->origin().isEmpty());
@@ -112,7 +112,7 @@ void KNSBackendTest::testReviews()
     const QVector<AbstractResource *> resources = getAllResources(m_backend);
     AbstractReviewsBackend *rev = m_backend->reviewsBackend();
     QVERIFY(!rev->hasCredentials());
-    foreach (AbstractResource *res, resources) {
+    for (AbstractResource *res : resources) {
         Rating *r = rev->ratingForApplication(res);
         QVERIFY(r);
         QCOMPARE(r->packageName(), res->packageName());
@@ -166,3 +166,5 @@ void KNSBackendTest::testResourceByUrlResourcesModel()
     });
     QCOMPARE(res.count(), 0);
 }
+
+#include "moc_KNSBackendTest.cpp"
