@@ -20,7 +20,8 @@ void AbstractBackendUpdater::cancel()
 
 void AbstractBackendUpdater::fetchChangelog() const
 {
-    foreach (auto res, toUpdate()) {
+    const auto toUpd = toUpdate();
+    for (auto res : toUpd) {
         res->fetchChangelog();
     }
 }
@@ -34,12 +35,31 @@ void AbstractBackendUpdater::enableNeedsReboot()
     Q_EMIT needsRebootChanged();
 }
 
+void AbstractBackendUpdater::enableReadyToReboot()
+{
+    m_readyToReboot = true;
+}
+
 bool AbstractBackendUpdater::needsReboot() const
 {
     return m_needsReboot;
 }
 
+bool AbstractBackendUpdater::isReadyToReboot() const
+{
+    return m_readyToReboot;
+}
+
 void AbstractBackendUpdater::setOfflineUpdates(bool useOfflineUpdates)
 {
     Q_UNUSED(useOfflineUpdates);
 }
+
+void AbstractBackendUpdater::setErrorMessage(const QString &errorMessage)
+{
+    if (errorMessage == m_errorMessage) {
+        return;
+    }
+    m_errorMessage = errorMessage;
+    Q_EMIT errorMessageChanged();
+}
